==> xld-ci-explorer-data-9.0.2.jar: xld/scripts/core/create-applications.py <==
# Deployment packages

longString = ' very very very very very very very very very very very very very very very very very very very very very very very very very very very very very long string'

create_ci('Applications/AppForUpdateScenario', 'udm.Application')
create_ci('Applications/AppForHistory', 'udm.Application')
create_ci('Applications/AppWithArtifacts', 'udm.Application')
create_ci('Applications/AppWithEmbeddedDeployeds', 'udm.Application')
create_ci('Applications/CommandsFromDictionaryApp', 'udm.Application')
create_ci('Applications/CompositeApp', 'udm.Application')
create_ci('Applications/DependentTestApp', 'udm.Application')
create_ci('Applications/EmptyTestApp', 'udm.Application')
create_ci('Applications/ExampleApp', 'udm.Application')
create_ci('Applications/LongRunningApp', 'udm.Application')
create_ci('Applications/MultiCommandApp', 'udm.Application')
create_ci('Applications/MyPackage', 'udm.Application')
create_ci('Applications/WithoutPipeline', 'udm.Application')
create_ci('Applications/TestApp', 'udm.Application')
create_ci('Applications/SatelliteApp', 'udm.Application')
create_ci('Applications/TestAppWithInvalidDeployed', 'udm.Application')
create_ci("Applications/ZApp%s" % longString, 'udm.Application')
create_ci("Applications/Long\"Script\"App", 'udm.Application')
create_ci("Applications/CiWith%1", 'udm.Application')
create_ci("Applications/CiWith%%12", 'udm.Application')
create_ci("Applications/ToSchedule", 'udm.Application')
create_ci("Applications/BlankApp", 'udm.Application')
create_ci("Applications/XLApplication", 'xl.Application')
create_ci('Applications/AppForSameHostScenario', 'udm.Application')

create_ci('Applications/AppForUpdateScenario/1.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForUpdateScenario/2.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForUpdateScenario/3.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForHistory/1.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForHistory/2.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForHistory/3.0', 'udm.DeploymentPackage')
create_ci('Applications/AppWithArtifacts/1.0', 'udm.DeploymentPackage')
create_ci('Applications/AppWithEmbeddedDeployeds/1.0', 'udm.DeploymentPackage')
create_ci('Applications/DependentTestApp/1.0', 'udm.DeploymentPackage',
          {'applicationDependencies': {'TestApp': '1.0'}})
create_ci('Applications/EmptyTestApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/ExampleApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/ExampleApp/2.0', 'udm.DeploymentPackage')
create_ci('Applications/LongRunningApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/MultiCommandApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/MyPackage/1.0', 'test-ci.MyPackage')
create_ci('Applications/WithoutPipeline/1.0', 'udm.DeploymentPackage')
create_ci('Applications/TestApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/TestAppWithInvalidDeployed/1.0', 'xl.DeploymentPackage')
create_ci('Applications/CommandsFromDictionaryApp/1.0', 'udm.DeploymentPackage')
create_ci("Applications/ZApp%s/1.0" % longString, 'udm.DeploymentPackage')
create_ci("Applications/Long\"Script\"App/1.0", 'udm.DeploymentPackage')
create_ci("Applications/CiWith%1/1.0", 'udm.DeploymentPackage')
create_ci("Applications/CiWith%%12/1.0", 'udm.DeploymentPackage')
create_ci("Applications/ToSchedule/1.0", 'udm.DeploymentPackage')
create_ci("Applications/XLApplication/1.0", 'udm.DeploymentPackage')
create_ci("Applications/XLApplication/2.0", 'udm.DeploymentPackage')
create_ci("Applications/XLApplication/3.0", 'udm.DeploymentPackage')
create_ci('Applications/CompositeApp/1.0', 'udm.CompositePackage', {
    'packages': ['Applications/LongRunningApp/1.0', 'Applications/TestApp/1.0']})
create_ci("Applications/AppForSameHostScenario/1.0", 'udm.DeploymentPackage')

for i in range(1, 100):
    appId = 'Applications/SatelliteApp/' + str(i) + '.0'
    create_ci(appId, 'udm.DeploymentPackage')
    create_ci(appId + '/cmd', 'cmd.Command', {'commandLine': 'sleep 1'})

create_ci('Applications/TestApp/1.0/Command', 'cmd.Command',
          {'commandLine': 'date', 'undoCommandLine': 'sleep 3'})
create_ci('Applications/DependentTestApp/1.0/SomeCommand', 'cmd.Command', {'commandLine': 'date'})
create_ci('Applications/TestAppWithInvalidDeployed/1.0/InvalidCommand', 'cmd.Command',
          {'name': 'Command', 'undoCommandLine': 'sleep 3'})
create_ci('Applications/TestAppWithInvalidDeployed/1.0/commandWithPlaceholder', 'cmd.Command',
          {'name': 'Command', 'undoCommandLine': '{{PLACE_HOLDER}}'})
create_ci('Applications/XLApplication/1.0/CommandForApplication', 'cmd.Command',
          {'commandLine': 'date', 'undoCommandLine': 'sleep 3'})
create_ci('Applications/XLApplication/2.0/CommandForApplication', 'cmd.Command',
          {'commandLine': 'date', 'undoCommandLine': 'sleep 3'})
create_ci('Applications/XLApplication/3.0/CommandForApplication', 'cmd.Command',
          {'commandLine': 'date', 'undoCommandLine': 'sleep 3'})

for x in range(1, 5):
    create_ci("Applications/LongRunningApp/1.0/SleepCommand%d" % x, 'cmd.Command',
              {'commandLine': 'sleep 3'})
    create_ci("Applications/CommandsFromDictionaryApp/1.0/cmd%d" % x, 'cmd.Command',
              {'commandLine': '{{cmd}}'})

for x in range(1, 15):
    create_ci("Applications/MultiCommandApp/1.0/cmd%d" % x, 'cmd.Command',
              {'commandLine': 'sleep 1'})

create_ci('Applications/AppWithArtifacts/1.0/google', 'file.File',
          {'fileUri': 'https://www.google.com'})
create_ci('Applications/AppWithEmbeddedDeployeds/1.0/Primary', 'example.ExamplePrimary')
create_ci('Applications/AppWithEmbeddedDeployeds/1.0/Primary/Embedded',
          'example.PrimaryEmbeddedDeployed')
create_ci('Applications/AppWithEmbeddedDeployeds/1.0/Primary/Embedded/Secondary',
          'example.EmbeddedVolumeSpec')
create_ci('Applications/ExampleApp/1.0/google', 'example.Artifact',
          {'fileUri': 'https://www.google.com'})
create_ci('Applications/Long\"Script\"App/1.0/LongScript', 'example.LongScriptDeployable')

create_ci('Applications/AppForUpdateScenario/1.0/SleepCommand1', 'cmd.Command',
          {'commandLine': 'sleep 10'})
create_ci('Applications/AppForUpdateScenario/2.0/SleepCommand2', 'cmd.Command',
          {'commandLine': 'sleep 3'})
create_ci('Applications/AppForUpdateScenario/3.0/SleepCommand3', 'cmd.Command',
          {'commandLine': 'sleep 5'})
create_ci('Applications/AppForUpdateScenario/3.0/SleepCommand3_1', 'cmd.Command',
          {'commandLine': 'sleep 5'})
for x in range(1, 5):
    create_ci("Applications/ZApp%s/1.0/Cmd%d %s" % (longString, x, longString), 'cmd.Command',
              {'commandLine': 'ls'})

create_ci('Applications/ToDeploy', 'core.Directory')

for x in range(1, 10):
    create_ci("Applications/ToDeploy/AppToDeploy%s" % x, 'udm.Application')
    create_ci("Applications/ToDeploy/AppToDeploy%s/1.0" % x, 'udm.DeploymentPackage')
    create_ci("Applications/ToDeploy/AppToDeploy%s/1.0/myCommand-%s" % (x, x), 'cmd.Command',
              {'commandLine': 'sleep 1'})

create_ci("Applications/AppForSandbox", 'udm.Application')
create_ci("Applications/AppForSandbox/1.0", 'udm.DeploymentPackage')
create_ci("Applications/AppForSandbox/1.0/staging-cmd", 'cmd.Command', {'commandLine': 'sleep 1'})

create_ci('Applications/DependentApp', 'udm.Application')
create_ci('Applications/AppWithDependentApp', 'udm.Application')
create_ci('Applications/DependentApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/AppWithDependentApp/1.0', 'udm.DeploymentPackage',
          {'applicationDependencies': {'DependentApp': '1.0'}})
create_ci('Applications/DependentApp/1.0/Command', 'cmd.Command', {'commandLine': '{{cmd}}'})

## DEPL-14469
create_ci('Applications/DEPL-14469', 'core.Directory')
create_ci('Applications/DEPL-14469/DEPL-14469-1', 'udm.Application')
create_ci('Applications/DEPL-14469/DEPL-14469-1/1.0', 'udm.DeploymentPackage')
create_ci('Applications/DEPL-14469/DEPL-14469-1/1.0/SleepCommand1', 'cmd.Command', {'commandLine': 'sleep 3'})

create_ci('Applications/DEPL-14469/DEPL-14469-2', 'udm.Application')
create_ci('Applications/DEPL-14469/DEPL-14469-2/1.0', 'udm.DeploymentPackage')
create_ci('Applications/DEPL-14469/DEPL-14469-2/1.0/SleepCommand2', 'cmd.Command', {'commandLine': 'sleep 5'})

create_ci('Applications/DEPL-14469/DEPL-14469-composite', 'udm.Application')
create_ci('Applications/DEPL-14469/DEPL-14469-composite/1.0', 'udm.CompositePackage', {
    'packages': ['Applications/DEPL-14469/DEPL-14469-1/1.0', 'Applications/DEPL-14469/DEPL-14469-2/1.0']
})

create_ci('Applications/AppToRename', 'udm.Application')

==> xld-ci-explorer-data-10.1.0-831.1703.jar: xld/scripts/core/create-applications.py <==
# Deployment packages

longString = ' very very very very very very very very very very very very very very very very very very very very very very very very very very very very very long string'

create_ci('Applications/AppForUpdateScenario', 'udm.Application')
create_ci('Applications/AppForHistory', 'udm.Application')
create_ci('Applications/AppWithArtifacts', 'udm.Application')
create_ci('Applications/AppWithEmbeddedDeployeds', 'udm.Application')
create_ci('Applications/CommandsFromDictionaryApp', 'udm.Application')
create_ci('Applications/CompositeApp', 'udm.Application')
create_ci('Applications/DependentTestApp', 'udm.Application')
create_ci('Applications/EmptyTestApp', 'udm.Application')
create_ci('Applications/ExampleApp', 'udm.Application')
create_ci('Applications/LongRunningApp', 'udm.Application')
create_ci('Applications/MultiCommandApp', 'udm.Application')
create_ci('Applications/MyPackage', 'udm.Application')
create_ci('Applications/WithoutPipeline', 'udm.Application')
create_ci('Applications/TestApp', 'udm.Application')
create_ci('Applications/SatelliteApp', 'udm.Application')
create_ci('Applications/TestAppWithInvalidDeployed', 'udm.Application')
create_ci("Applications/ZApp%s" % longString, 'udm.Application')
create_ci("Applications/Long\"Script\"App", 'udm.Application')
create_ci("Applications/CiWith%1", 'udm.Application')
create_ci("Applications/CiWith%%12", 'udm.Application')
create_ci("Applications/ToSchedule", 'udm.Application')
create_ci("Applications/BlankApp", 'udm.Application')
create_ci("Applications/XLApplication", 'xl.Application')
create_ci('Applications/AppForSameHostScenario', 'udm.Application')

create_ci('Applications/AppForUpdateScenario/1.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForUpdateScenario/2.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForUpdateScenario/3.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForHistory/1.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForHistory/2.0', 'udm.DeploymentPackage')
create_ci('Applications/AppForHistory/3.0', 'udm.DeploymentPackage')
create_ci('Applications/AppWithArtifacts/1.0', 'udm.DeploymentPackage')
create_ci('Applications/AppWithEmbeddedDeployeds/1.0', 'udm.DeploymentPackage')
create_ci('Applications/DependentTestApp/1.0', 'udm.DeploymentPackage',
          {'applicationDependencies': {'TestApp': '1.0'}})
create_ci('Applications/EmptyTestApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/ExampleApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/ExampleApp/2.0', 'udm.DeploymentPackage')
create_ci('Applications/LongRunningApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/MultiCommandApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/MyPackage/1.0', 'test-ci.MyPackage')
create_ci('Applications/WithoutPipeline/1.0', 'udm.DeploymentPackage')
create_ci('Applications/TestApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/TestAppWithInvalidDeployed/1.0', 'xl.DeploymentPackage')
create_ci('Applications/CommandsFromDictionaryApp/1.0', 'udm.DeploymentPackage')
create_ci("Applications/ZApp%s/1.0" % longString, 'udm.DeploymentPackage')
create_ci("Applications/Long\"Script\"App/1.0", 'udm.DeploymentPackage')
create_ci("Applications/CiWith%1/1.0", 'udm.DeploymentPackage')
create_ci("Applications/CiWith%%12/1.0", 'udm.DeploymentPackage')
create_ci("Applications/ToSchedule/1.0", 'udm.DeploymentPackage')
create_ci("Applications/XLApplication/1.0", 'udm.DeploymentPackage')
create_ci("Applications/XLApplication/2.0", 'udm.DeploymentPackage')
create_ci("Applications/XLApplication/3.0", 'udm.DeploymentPackage')
create_ci('Applications/CompositeApp/1.0', 'udm.CompositePackage', {
    'packages': ['Applications/LongRunningApp/1.0', 'Applications/TestApp/1.0']})
create_ci("Applications/AppForSameHostScenario/1.0", 'udm.DeploymentPackage')

for i in range(1, 100):
    appId = 'Applications/SatelliteApp/' + str(i) + '.0'
    create_ci(appId, 'udm.DeploymentPackage')
    create_ci(appId + '/cmd', 'cmd.Command', {'commandLine': 'sleep 1'})

create_ci('Applications/TestApp/1.0/Command', 'cmd.Command',
          {'commandLine': 'date', 'undoCommandLine': 'sleep 3'})
create_ci('Applications/DependentTestApp/1.0/SomeCommand', 'cmd.Command', {'commandLine': 'date'})
create_ci('Applications/TestAppWithInvalidDeployed/1.0/InvalidCommand', 'cmd.Command',
          {'name': 'Command', 'undoCommandLine': 'sleep 3'})
create_ci('Applications/TestAppWithInvalidDeployed/1.0/commandWithPlaceholder', 'cmd.Command',
          {'name': 'Command', 'undoCommandLine': '{{PLACE_HOLDER}}'})
create_ci('Applications/XLApplication/1.0/CommandForApplication', 'cmd.Command',
          {'commandLine': 'date', 'undoCommandLine': 'sleep 3'})
create_ci('Applications/XLApplication/2.0/CommandForApplication', 'cmd.Command',
          {'commandLine': 'date', 'undoCommandLine': 'sleep 3'})
create_ci('Applications/XLApplication/3.0/CommandForApplication', 'cmd.Command',
          {'commandLine': 'date', 'undoCommandLine': 'sleep 3'})

for x in range(1, 5):
    create_ci("Applications/LongRunningApp/1.0/SleepCommand%d" % x, 'cmd.Command',
              {'commandLine': 'sleep 3'})
    create_ci("Applications/CommandsFromDictionaryApp/1.0/cmd%d" % x, 'cmd.Command',
              {'commandLine': '{{cmd}}'})

for x in range(1, 15):
    create_ci("Applications/MultiCommandApp/1.0/cmd%d" % x, 'cmd.Command',
              {'commandLine': 'sleep 1'})

create_ci('Applications/AppWithArtifacts/1.0/google', 'file.File',
          {'fileUri': 'https://www.google.com'})
create_ci('Applications/AppWithEmbeddedDeployeds/1.0/Primary', 'example.ExamplePrimary')
create_ci('Applications/AppWithEmbeddedDeployeds/1.0/Primary/Embedded',
          'example.PrimaryEmbeddedDeployed')
create_ci('Applications/AppWithEmbeddedDeployeds/1.0/Primary/Embedded/Secondary',
          'example.EmbeddedVolumeSpec')
create_ci('Applications/ExampleApp/1.0/google', 'example.Artifact',
          {'fileUri': 'https://www.google.com'})
create_ci('Applications/Long\"Script\"App/1.0/LongScript', 'example.LongScriptDeployable')

create_ci('Applications/AppForUpdateScenario/1.0/SleepCommand1', 'cmd.Command',
          {'commandLine': 'sleep 10'})
create_ci('Applications/AppForUpdateScenario/2.0/SleepCommand2', 'cmd.Command',
          {'commandLine': 'sleep 3'})
create_ci('Applications/AppForUpdateScenario/3.0/SleepCommand3', 'cmd.Command',
          {'commandLine': 'sleep 5'})
create_ci('Applications/AppForUpdateScenario/3.0/SleepCommand3_1', 'cmd.Command',
          {'commandLine': 'sleep 5'})
for x in range(1, 5):
    create_ci("Applications/ZApp%s/1.0/Cmd%d %s" % (longString, x, longString), 'cmd.Command',
              {'commandLine': 'ls'})

create_ci('Applications/ToDeploy', 'core.Directory')

for x in range(1, 10):
    create_ci("Applications/ToDeploy/AppToDeploy%s" % x, 'udm.Application')
    create_ci("Applications/ToDeploy/AppToDeploy%s/1.0" % x, 'udm.DeploymentPackage')
    create_ci("Applications/ToDeploy/AppToDeploy%s/1.0/myCommand-%s" % (x, x), 'cmd.Command',
              {'commandLine': 'sleep 1'})

create_ci("Applications/AppForSandbox", 'udm.Application')
create_ci("Applications/AppForSandbox/1.0", 'udm.DeploymentPackage')
create_ci("Applications/AppForSandbox/1.0/staging-cmd", 'cmd.Command', {'commandLine': 'sleep 1'})

create_ci('Applications/DependentApp', 'udm.Application')
create_ci('Applications/AppWithDependentApp', 'udm.Application')
create_ci('Applications/DependentApp/1.0', 'udm.DeploymentPackage')
create_ci('Applications/AppWithDependentApp/1.0', 'udm.DeploymentPackage',
          {'applicationDependencies': {'DependentApp': '1.0'}})
create_ci('Applications/DependentApp/1.0/Command', 'cmd.Command', {'commandLine': '{{cmd}}'})

## DEPL-14469
create_ci('Applications/DEPL-14469', 'core.Directory')
create_ci('Applications/DEPL-14469/DEPL-14469-1', 'udm.Application')
create_ci('Applications/DEPL-14469/DEPL-14469-1/1.0', 'udm.DeploymentPackage')
create_ci('Applications/DEPL-14469/DEPL-14469-1/1.0/SleepCommand1', 'cmd.Command', {'commandLine': 'sleep 3'})

create_ci('Applications/DEPL-14469/DEPL-14469-2', 'udm.Application')
create_ci('Applications/DEPL-14469/DEPL-14469-2/1.0', 'udm.DeploymentPackage')
create_ci('Applications/DEPL-14469/DEPL-14469-2/1.0/SleepCommand2', 'cmd.Command', {'commandLine': 'sleep 5'})

create_ci('Applications/DEPL-14469/DEPL-14469-composite', 'udm.Application')
create_ci('Applications/DEPL-14469/DEPL-14469-composite/1.0', 'udm.CompositePackage', {
    'packages': ['Applications/DEPL-14469/DEPL-14469-1/1.0', 'Applications/DEPL-14469/DEPL-14469-2/1.0']
})

create_ci('Applications/AppToRename', 'udm.Application')

import_package('EDI_FLOWS-8.21.0.dar')
import_package('EDI_FLOWS-8.22.0.dar')
import_package('PlaceholderAppWithArtifacts-1.0.dar')
